@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: ZephyrusSettings.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: ZephyrusSettings.py 11376 2019-03-03 14:21:00Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2019-03-03 23:21:00 +0900 (週日, 03 三月 2019) $
+# $Revision: 11376 $
 """
 Default settings for this project if it can't import settings.
 """
@@ -152,7 +152,7 @@ MIDDLEWARE_CLASSES = (
 )
 
 INSTALLED_APPS = (
-    'djangocms_admin_style',
+    #'djangocms_admin_style',
     'django.contrib.auth',
     'django.contrib.contenttypes',
     'django.contrib.sessions',
