@@ -252,6 +252,18 @@ def attachSettings(settingsDict):
                 },
             }
 
-        update(settingsDict, HAYSTACK_SETTINGS)
+        if not 'HAYSTACK_CONNECTIONS' in settingsDict:
+            update(settingsDict, HAYSTACK_SETTINGS)
+        else:
+            for key in settingsDict['HAYSTACK_CONNECTIONS']:
+                value = settingsDict['HAYSTACK_CONNECTIONS'][key]
+                if 'EXCLUDED_INDEXES' in value:
+                    value['EXCLUDED_INDEXES'].append(
+                        'aldryn_people.search_indexes.PeopleIndex')
+                else:
+                    value['EXCLUDED_INDEXES'] = [
+                        'aldryn_people.search_indexes.PeopleIndex',
+                    ]
+            
 
     
